@@ -8,7 +8,7 @@ class Parameter(Generic[T]):
 
     def __init__(self,
                  name: str,
-                 title: str,
+                 title: str = "",
                  description: str = "",
                  value: T = None,
                  optional: bool = False,
